Angles class

Angles class provides helpers to convert FixedAngles to degrees or radians.

Constructors

Angles()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fixedToDegrees(FixedAngles angle) double
fixedToDegrees converts an object of class FixedAngles to degrees
fixedToRadian(FixedAngles angle) double?
fixedToRadian converts an object of class FixedAngles to radians
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited